--------------------------------------------------------------------------------
--
-- Module Name      : mptl128_gtx6_interface
--
--                    Copyright 2009 by
--                    Alpha Data Parallel Systems Ltd.
--                    All Rights Reserved.
--
-- Original Author  : Andrew McCormick
-- Created          :
--
-- Modified By      :
-- Date             :
-- Change Notes     :
--
-- Description      : GTP Instantiation for 4x32 bit GTP MPTL-HSS link
--
--
-- Dependencies     :
--
-- Disclaimer       : THESE DESIGNS ARE PROVIDED "AS IS" WITH NO WARRANTY
--                    WHATSOEVER AND ALPHA DATA SPECIFICALLY DISCLAIMS ANY
--                    WARRANTIES IMPLIED OF MERCHANTABILITY, FITNESS FOR A
--                    PARTICULAR PURPOSE, OR AGAINST INFRINGEMENT.
--
--------------------------------------------------------------------------------




library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_misc.all;

library UNISIM;
use UNISIM.VCOMPONENTS.all;

entity mptl128_gtx6_interface is

  port (
    clkin           : in  std_logic;
    rst             : in  std_logic;
    ref_clk         : out std_logic;
    gtp_clk         : in  std_logic;
    gtp_clk2x       : in  std_logic;
    -- Connection to MPTL64HSS Buffers
    gtp_data_in     : in  std_logic_vector(127 downto 0);
    gtp_charisk_in  : in  std_logic_vector(15 downto 0);
    gtp_data_out    : out std_logic_vector(127 downto 0);
    gtp_charisk_out : out std_logic_vector(15 downto 0);
    -- Connection to Serial Ports
    tx_p            : out std_logic_vector(3 downto 0);
    tx_n            : out std_logic_vector(3 downto 0);
    rx_p            : in  std_logic_vector(3 downto 0);
    rx_n            : in  std_logic_vector(3 downto 0);
    -- Control
    loopback        : in  std_logic_vector(2 downto 0);
    config          : in  std_logic_vector(15 downto 0);
    rx_reset        : in  std_logic_vector(7 downto 0);
    en_comma_align  : in  std_logic;
    powerdown       : in  std_logic;
    pll_locked      : out std_logic;
    rx_status       : out std_logic_vector(23 downto 0);
    rx_loss_of_sync : out std_logic_vector(15 downto 0));

end mptl128_gtx6_interface;

architecture v6lx_x4 of mptl128_gtx6_interface is

  -- ground and tied_to_vcc_i signals
  signal tied_to_ground_i     : std_logic;
  signal tied_to_ground_vec_i : std_logic_vector(63 downto 0);
  signal tied_to_vcc_i        : std_logic;
  signal tied_to_vcc_vec_i    : std_logic_vector(63 downto 0);



  signal txoutclk : std_logic_vector(3 downto 0);

  signal  gtx0_mgtrefclk           :   std_logic_vector(1 downto 0);

  --constant TXDIFFCTRL : std_logic_vector(15 downto 0) := X"9999";  --790mV
  constant TXDIFFCTRL : std_logic_vector(15 downto 0) := X"8888";  --790mV
  --constant TXDIFFCTRL : std_logic_vector(15 downto 0) := X"4444";  --290mV
   constant TXPREEMPHASIS : std_logic_vector(15 downto 0) := X"0000";
  -- constant TXPOSTEMPHASIS : std_logic_vector(31 downto 0) := X"09091218";
  -- constant TXPOSTEMPHASIS : std_logic_vector(31 downto 0) := X"13111111";
   constant TXPOSTEMPHASIS : std_logic_vector(31 downto 0) := X"07070707";

--   signal TXDIFFCTRL : std_logic_vector(15 downto 0);
--   signal TXPREEMPHASIS : std_logic_vector(15 downto 0);
--   signal TXPOSTEMPHASIS : std_logic_vector(31 downto 0);


  signal rx_reset_done : std_logic_vector(3 downto 0);
  signal align : std_logic_vector(3 downto 0);

  signal pll_lock : std_logic_vector(3 downto 0);
  signal rpll_lock : std_logic_vector(3 downto 0);

  signal dfeeyedacmon : std_logic_vector(19 downto 0);

  -- Internal signals
  signal gtp_data_out_int    : std_logic_vector(127 downto 0);
  signal gtp_charisk_out_int : std_logic_vector(15 downto 0);
  signal rx_loss_of_sync_int : std_logic_vector(7 downto 0);

begin  -- rtl

  -- Ensure gtp_data and gtp_charisk are never undefined ('X' => '0')
  gen_gtp_data : for i in 0 to 127 generate
    gtp_data_out(i) <= '1' when gtp_data_out_int(i) = '1' else '0';
  end generate;

  gen_gtp_charisk : for i in 0 to 15 generate
    gtp_charisk_out(i) <= '1' when gtp_charisk_out_int(i) = '1' else '0';
  end generate;

  -- Ensure rx_los is never undefined ('X' => '1')
  gen_rx_loss_of_sync : for i in 0 to 7 generate
    rx_loss_of_sync(i) <= '0' when rx_loss_of_sync_int(i) = '0' else '1';
  end generate;


--   TXDIFFCTRL <= config(3 downto 0) & config(3 downto 0) & config(3 downto 0) & config(3 downto 0);
--   TXPREEMPHASIS <= config(7 downto 4) &  config(7 downto 4) &  config(7 downto 4) &  config(7 downto 4);
--   TXPOSTEMPHASIS <= config(15 downto 8) &  config(15 downto 8) &  config(15 downto 8) & config(15 downto 8);

  ---------------------------  Static signal Assignments ---------------------

  tied_to_ground_i                  <= '0';
  tied_to_ground_vec_i(63 downto 0) <= (others => '0');
  tied_to_vcc_i                     <= '1';
  tied_to_vcc_vec_i(63 downto 0)    <= (others => '1');

  ref_clk <= txoutclk(0);

  gtx0_mgtrefclk <= (tied_to_ground_i & clkin);
  pll_locked <= pll_lock(0);



  gen_gtx: for i in 0 to 3 generate


  gtxe1_0 : GTXE1
    generic map
    (

      --_______________________ Simulation-Only Attributes ___________________

      SIM_RECEIVER_DETECT_PASS => (true),

      SIM_GTXRESET_SPEEDUP => (1),

      SIM_TX_ELEC_IDLE_LEVEL => ("X"),

      SIM_VERSION         => ("1.0"),
      SIM_TXREFCLK_SOURCE => ("000"),
      SIM_RXREFCLK_SOURCE => ("000"),


      ----------------------------TX PLL----------------------------
      TX_CLK_SOURCE      => ("TXPLL"),
      TX_OVERSAMPLE_MODE => (false),
      TXPLL_COM_CFG      => (x"21680a"),
      TXPLL_CP_CFG       => (x"0D"),
      TXPLL_DIVSEL_FB    => (2),        -- 4 for 125MHz Ref, 2 for 250MHz Ref
      TXPLL_DIVSEL_OUT   => (1),        --1
      TXPLL_DIVSEL_REF   => (1),
      TXPLL_DIVSEL45_FB  => (5),        -- 5 for 5GHz
      TXPLL_LKDET_CFG    => ("111"),
      TX_CLK25_DIVIDER   => (9),
      TXPLL_SATA         => ("00"),
      TX_TDCC_CFG        => ("11"),
      PMA_CAS_CLK_EN     => (false),
      POWER_SAVE         => ("0000110100"),

      -------------------------TX Interface-------------------------
      GEN_TXUSRCLK  => (false),
      TX_DATA_WIDTH => (40),
      TX_USRCLK_CFG => (x"00"),
      TXOUTCLK_CTRL => ("TXPLLREFCLK_DIV1"),
      TXOUTCLK_DLY  => ("0000000000"),

      --------------TX Buffering and Phase Alignment----------------
      TX_PMADATA_OPT          => ('0'),
      PMA_TX_CFG              => (x"80082"),
      TX_BUFFER_USE           => (true),
      TX_BYTECLK_CFG          => (x"00"),
      TX_EN_RATE_RESET_BUF    => (true),
      TX_XCLK_SEL             => ("TXOUT"),
      TX_DLYALIGN_CTRINC      => ("0100"),
      TX_DLYALIGN_LPFINC      => ("0110"),
      TX_DLYALIGN_MONSEL      => ("000"),
      TX_DLYALIGN_OVRDSETTING => ("10000000"),

      -------------------------TX Gearbox---------------------------
      GEARBOX_ENDEC => ("000"),
      TXGEARBOX_USE => (false),

      ----------------TX Driver and OOB Signalling------------------
      TX_DRIVE_MODE          => ("DIRECT"),
      TX_IDLE_ASSERT_DELAY   => ("101"),
      TX_IDLE_DEASSERT_DELAY => ("011"),
      TXDRIVE_LOOPBACK_HIZ   => (false),
      TXDRIVE_LOOPBACK_PD    => (false),

      --------------TX Pipe Control for PCI Express/SATA------------
      COM_BURST_VAL => ("1111"),

      ------------------TX Attributes for PCI Express---------------
      TX_DEEMPH_0      => ("11010"),
      TX_DEEMPH_1      => ("10000"),
      TX_MARGIN_FULL_0 => ("1001110"),
      TX_MARGIN_FULL_1 => ("1001001"),
      TX_MARGIN_FULL_2 => ("1000101"),
      TX_MARGIN_FULL_3 => ("1000010"),
      TX_MARGIN_FULL_4 => ("1000000"),
      TX_MARGIN_LOW_0  => ("1000110"),
      TX_MARGIN_LOW_1  => ("1000100"),
      TX_MARGIN_LOW_2  => ("1000010"),
      TX_MARGIN_LOW_3  => ("1000000"),
      TX_MARGIN_LOW_4  => ("1000000"),

      ----------------------------RX PLL----------------------------
      RX_OVERSAMPLE_MODE => (false),
      RXPLL_COM_CFG      => (x"21680a"),
      RXPLL_CP_CFG       => (x"0D"),
      RXPLL_DIVSEL_FB    => (2), -- 4 for 125MHz Ref, 2 for 250MHz Ref
      RXPLL_DIVSEL_OUT   => (1),
      RXPLL_DIVSEL_REF   => (1),
      RXPLL_DIVSEL45_FB  => (5),        -- 5 for 5 GHz operation
      RXPLL_LKDET_CFG    => ("111"),
      RX_CLK25_DIVIDER   => (9),

      -------------------------RX Interface-------------------------
      GEN_RXUSRCLK  => (false),
      RX_DATA_WIDTH => (40),
      RXRECCLK_CTRL => ("RXPLLREFCLK_DIV1"),
      RXRECCLK_DLY  => ("0000000000"),
      RXUSRCLK_DLY  => (x"0000"),

      ----------RX Driver,OOB signalling,Coupling and Eq.,CDR-------
      AC_CAP_DIS          => (false),
      CDR_PH_ADJ_TIME     => ("10100"),
      OOBDETECT_THRESHOLD => ("011"),
      PMA_CDR_SCAN        => (x"640404C"),
      PMA_RX_CFG          => (x"05ce048"),
      RCV_TERM_GND        => (false),
      RCV_TERM_VTTRX      => (true),
      RX_EN_IDLE_HOLD_CDR => (true),
      RX_EN_IDLE_RESET_FR => (true),
      RX_EN_IDLE_RESET_PH => (true),
      TX_DETECT_RX_CFG    => (x"1832"),
      TERMINATION_CTRL    => ("00000"),
      TERMINATION_OVRD    => (false),
      CM_TRIM             => ("01"),
      PMA_RXSYNC_CFG      => (x"00"),
      PMA_CFG             => (x"0040000040000000003"),
      BGTEST_CFG          => ("00"),
      BIAS_CFG            => (x"00000"),

      --------------RX Decision Feedback Equalizer(DFE)-------------
      DFE_CAL_TIME        => ("01100"),
      DFE_CFG             => ("00011011"),
      RX_EN_IDLE_HOLD_DFE => (true),
      RX_EYE_OFFSET       => (x"4C"),
      RX_EYE_SCANMODE     => ("00"),

      -------------------------PRBS Detection-----------------------

      ------------------Comma Detection and Alignment---------------
      ALIGN_COMMA_WORD     => (2),
      COMMA_10B_ENABLE     => ("1111111111"),
      COMMA_DOUBLE         => (false),
      DEC_MCOMMA_DETECT    => (false),
      DEC_PCOMMA_DETECT    => (false),
      DEC_VALID_COMMA_ONLY => (false),
      MCOMMA_10B_VALUE     => ("1010000011"),
      MCOMMA_DETECT        => (true),
      PCOMMA_10B_VALUE     => ("0101111100"),
      PCOMMA_DETECT        => (true),
      RX_DECODE_SEQ_MATCH  => (true),
      RX_SLIDE_AUTO_WAIT   => (5),
      RX_SLIDE_MODE        => ("OFF"),
      SHOW_REALIGN_COMMA   => (true),

      -----------------RX Loss-of-sync State Machine----------------
      RX_LOS_INVALID_INCR => (8),
      RX_LOS_THRESHOLD    => (128),
      RX_LOSS_OF_SYNC_FSM => (false),

      -------------------------RX Gearbox---------------------------
      RXGEARBOX_USE => (false),

      -------------RX Elastic Buffer and Phase alignment------------
      RX_BUFFER_USE            => (true),
      RX_EN_IDLE_RESET_BUF     => (true),
      RX_EN_MODE_RESET_BUF     => (true),
      RX_EN_RATE_RESET_BUF     => (true),
      RX_EN_REALIGN_RESET_BUF  => (true),
      RX_EN_REALIGN_RESET_BUF2 => (true),
      RX_FIFO_ADDR_MODE        => ("FULL"),
      RX_IDLE_HI_CNT           => ("1000"),
      RX_IDLE_LO_CNT           => ("0000"),
      RX_XCLK_SEL              => ("RXREC"),
      RX_DLYALIGN_CTRINC       => ("0100"),
      RX_DLYALIGN_EDGESET      => ("00010"),
      RX_DLYALIGN_LPFINC       => ("0110"),
      RX_DLYALIGN_MONSEL       => ("000"),
      RX_DLYALIGN_OVRDSETTING  => ("10000000"),

      ------------------------Clock Correction----------------------
      CLK_COR_ADJ_LEN          => (1),
      CLK_COR_DET_LEN          => (1),
      CLK_COR_INSERT_IDLE_FLAG => (false),
      CLK_COR_KEEP_IDLE        => (false),
      CLK_COR_MAX_LAT          => (16),
      CLK_COR_MIN_LAT          => (14),
      CLK_COR_PRECEDENCE       => (true),
      CLK_COR_REPEAT_WAIT      => (0),
      CLK_COR_SEQ_1_1          => ("0100000000"),
      CLK_COR_SEQ_1_2          => ("0000000000"),
      CLK_COR_SEQ_1_3          => ("0000000000"),
      CLK_COR_SEQ_1_4          => ("0000000000"),
      CLK_COR_SEQ_1_ENABLE     => ("1111"),
      CLK_COR_SEQ_2_1          => ("0100000000"),
      CLK_COR_SEQ_2_2          => ("0000000000"),
      CLK_COR_SEQ_2_3          => ("0000000000"),
      CLK_COR_SEQ_2_4          => ("0000000000"),
      CLK_COR_SEQ_2_ENABLE     => ("1111"),
      CLK_COR_SEQ_2_USE        => (false),
      CLK_CORRECT_USE          => (false),

      ------------------------Channel Bonding----------------------
      CHAN_BOND_1_MAX_SKEW   => (1),
      CHAN_BOND_2_MAX_SKEW   => (1),
      CHAN_BOND_KEEP_ALIGN   => (false),
      CHAN_BOND_SEQ_1_1      => ("0000000000"),
      CHAN_BOND_SEQ_1_2      => ("0000000000"),
      CHAN_BOND_SEQ_1_3      => ("0000000000"),
      CHAN_BOND_SEQ_1_4      => ("0000000000"),
      CHAN_BOND_SEQ_1_ENABLE => ("1111"),
      CHAN_BOND_SEQ_2_1      => ("0000000000"),
      CHAN_BOND_SEQ_2_2      => ("0000000000"),
      CHAN_BOND_SEQ_2_3      => ("0000000000"),
      CHAN_BOND_SEQ_2_4      => ("0000000000"),
      CHAN_BOND_SEQ_2_CFG    => ("00000"),
      CHAN_BOND_SEQ_2_ENABLE => ("1111"),
      CHAN_BOND_SEQ_2_USE    => (false),
      CHAN_BOND_SEQ_LEN      => (1),
      PCI_EXPRESS_MODE       => (false),

      -------------RX Attributes for PCI Express/SATA/SAS----------
      SAS_MAX_COMSAS     => (52),
      SAS_MIN_COMSAS     => (40),
      SATA_BURST_VAL     => ("100"),
      SATA_IDLE_VAL      => ("100"),
      SATA_MAX_BURST     => (9),
      SATA_MAX_INIT      => (27),
      SATA_MAX_WAKE      => (9),
      SATA_MIN_BURST     => (5),
      SATA_MIN_INIT      => (15),
      SATA_MIN_WAKE      => (5),
      TRANS_TIME_FROM_P2 => (x"03c"),
      TRANS_TIME_NON_P2  => (x"19"),
      TRANS_TIME_RATE    => (x"ff"),
      TRANS_TIME_TO_P2   => (x"064")


      )
    port map
    (
      ------------------------ Loopback and Powerdown Ports ----------------------
      LOOPBACK                 => loopback,
      RXPOWERDOWN              => tied_to_ground_vec_i(1 downto 0),
      TXPOWERDOWN              => tied_to_ground_vec_i(1 downto 0),
      -------------- Receive Ports - 64b66b and 64b67b Gearbox Ports -------------
      RXDATAVALID              => open,
      RXGEARBOXSLIP            => tied_to_ground_i,
      RXHEADER                 => open,
      RXHEADERVALID            => open,
      RXSTARTOFSEQ             => open,
      ----------------------- Receive Ports - 8b10b Decoder ----------------------
      RXCHARISCOMMA            => open,
--      RXCHARISK                => gtp_charisk_out(4*i+3 downto 4*i),
      RXCHARISK                => gtp_charisk_out_int(4*i+3 downto 4*i),
      RXDEC8B10BUSE            => tied_to_vcc_i,
      RXDISPERR    => open,
      RXNOTINTABLE => open,
      RXRUNDISP                => open,
      USRCODEERR               => tied_to_ground_i,
      ------------------- Receive Ports - Channel Bonding Ports ------------------
      RXCHANBONDSEQ            => open,
      RXCHBONDI                => tied_to_ground_vec_i(3 downto 0),
      RXCHBONDLEVEL            => tied_to_ground_vec_i(2 downto 0),
      RXCHBONDMASTER           => tied_to_ground_i,
      RXCHBONDO                => open,
      RXCHBONDSLAVE            => tied_to_ground_i,
      RXENCHANSYNC             => tied_to_ground_i,
      ------------------- Receive Ports - Clock Correction Ports -----------------
      RXCLKCORCNT              => open,
      --------------- Receive Ports - Comma Detection and Alignment --------------
      RXBYTEISALIGNED          => rx_status(3*i+2),
      RXBYTEREALIGN            => open,
      RXCOMMADET               => open,
      RXCOMMADETUSE            => tied_to_vcc_i,
      RXENMCOMMAALIGN          => align(i),
      RXENPCOMMAALIGN          => align(i),
      RXSLIDE                  => tied_to_ground_i,
      ----------------------- Receive Ports - PRBS Detection ---------------------
      PRBSCNTRESET             => tied_to_ground_i,
      RXENPRBSTST              => tied_to_ground_vec_i(2 downto 0),
      RXPRBSERR                => open,
      ------------------- Receive Ports - RX Data Path interface -----------------
--      RXDATA                   => gtp_data_out(32*i+31 downto 32*i),
      RXDATA                   => gtp_data_out_int(32*i+31 downto 32*i),
      RXRECCLK                 => open,
      RXRECCLKPCS              => open,
      RXRESET                  => rx_reset(i),
      RXUSRCLK                 => gtp_clk2x,
      RXUSRCLK2                => gtp_clk,
      ------------ Receive Ports - RX Decision Feedback Equalizer(DFE) -----------
      DFECLKDLYADJ             => tied_to_ground_vec_i(5 downto 0),
      DFECLKDLYADJMON          => open,
      DFEDLYOVRD               => tied_to_ground_i, --tied_to_vcc_i,
      DFEEYEDACMON             => dfeeyedacmon(5*i+4 downto 5*i),
      DFESENSCAL               => open,
      DFETAP1                  => tied_to_ground_vec_i(4 downto 0),
      DFETAP1MONITOR           => open,
      DFETAP2                  => tied_to_ground_vec_i(4 downto 0),
      DFETAP2MONITOR           => open,
      DFETAP3                  => tied_to_ground_vec_i(3 downto 0),
      DFETAP3MONITOR           => open,
      DFETAP4                  => tied_to_ground_vec_i(3 downto 0),
      DFETAP4MONITOR           => open,
      DFETAPOVRD               => tied_to_vcc_i,
      ------- Receive Ports - RX Driver,OOB signalling,Coupling and Eq.,CDR ------
      GATERXELECIDLE           => tied_to_ground_i,
      IGNORESIGDET             => tied_to_ground_i,
      RXCDRRESET               => rx_reset(i),
      RXELECIDLE               => open,
      RXEQMIX                  => "0000000011",
      RXN                      => rx_n(3-i),
      RXP                      => rx_p(3-i),
      -------- Receive Ports - RX Elastic Buffer and Phase Alignment Ports -------
      RXBUFRESET               => '0',--rx_reset(i),--tied_to_ground_i,
      RXBUFSTATUS              => open,--rx_status(3*i+2 downto 3*i),
      RXCHANISALIGNED          => open,
      RXCHANREALIGN            => open,
      RXDLYALIGNDISABLE        => '0', --tied_to_vcc_i,
      RXDLYALIGNMONITOR        => open,
      RXDLYALIGNOVERRIDE       => '1', --tied_to_ground_i,
      RXDLYALIGNRESET          => tied_to_ground_i,
      RXDLYALIGNSWPPRECURB     => tied_to_vcc_i,
      RXDLYALIGNUPDSW          => tied_to_ground_i,
      RXENPMAPHASEALIGN        => tied_to_ground_i,
      RXPMASETPHASE            => tied_to_ground_i,
      RXSTATUS                 => open,
      --------------- Receive Ports - RX Loss-of-sync State Machine --------------
--      RXLOSSOFSYNC             => rx_loss_of_sync(2*i+1 downto 2*i),
      RXLOSSOFSYNC             => rx_loss_of_sync_int(2*i+1 downto 2*i),
      ---------------------- Receive Ports - RX Oversampling ---------------------
      RXENSAMPLEALIGN          => tied_to_ground_i,
      RXOVERSAMPLEERR          => open,
      ------------------------ Receive Ports - RX PLL Ports ----------------------
      GREFCLKRX                => tied_to_ground_i,
      GTXRXRESET               => rst,
      MGTREFCLKRX              => gtx0_mgtrefclk,
      NORTHREFCLKRX            => tied_to_ground_vec_i(1 downto 0),
      PERFCLKRX                => tied_to_ground_i,
      PLLRXRESET               => rx_reset(i),
      RXPLLLKDET               => rpll_lock(i),
      RXPLLLKDETEN             => tied_to_vcc_i,
      RXPLLPOWERDOWN           => tied_to_ground_i,
      RXPLLREFSELDY            => tied_to_ground_vec_i(2 downto 0),
      RXRATE                   => tied_to_ground_vec_i(1 downto 0),
      RXRATEDONE               => open,
      RXRESETDONE              => rx_reset_done(i),
      SOUTHREFCLKRX            => tied_to_ground_vec_i(1 downto 0),
      -------------- Receive Ports - RX Pipe Control for PCI Express -------------
      PHYSTATUS                => open,
      RXVALID                  => open,
      ----------------- Receive Ports - RX Polarity Control Ports ----------------
      RXPOLARITY               => tied_to_ground_i,
      --------------------- Receive Ports - RX Ports for SATA --------------------
      COMINITDET               => open,
      COMSASDET                => open,
      COMWAKEDET               => open,
      ------------- Shared Ports - Dynamic Reconfiguration Port (DRP) ------------
      DADDR                    => tied_to_ground_vec_i(7 downto 0),
      DCLK                     => tied_to_ground_i,
      DEN                      => tied_to_ground_i,
      DI                       => tied_to_ground_vec_i(15 downto 0),
      DRDY                     => open,
      DRPDO                    => open,
      DWE                      => tied_to_ground_i,
      -------------- Transmit Ports - 64b66b and 64b67b Gearbox Ports ------------
      TXGEARBOXREADY           => open,
      TXHEADER                 => tied_to_ground_vec_i(2 downto 0),
      TXSEQUENCE               => tied_to_ground_vec_i(6 downto 0),
      TXSTARTSEQ               => tied_to_ground_i,
      ---------------- Transmit Ports - 8b10b Encoder Control Ports --------------
      TXBYPASS8B10B            => tied_to_ground_vec_i(3 downto 0),
      TXCHARDISPMODE           => tied_to_ground_vec_i(3 downto 0),
      TXCHARDISPVAL            => tied_to_ground_vec_i(3 downto 0),
      TXCHARISK                => gtp_charisk_in(4*i+3 downto 4*i),
      TXENC8B10BUSE            => tied_to_vcc_i,
      TXKERR                   => open,
      TXRUNDISP                => open,
      ------------------------- Transmit Ports - GTX Ports -----------------------
      GTXTEST                  => "1000000000000",
      MGTREFCLKFAB             => open,
      TSTCLK0                  => tied_to_ground_i,
      TSTCLK1                  => tied_to_ground_i,
      TSTIN                    => "11111111111111111111",
      TSTOUT                   => open,
      ------------------ Transmit Ports - TX Data Path interface -----------------
      TXDATA(31 downto 0)      => gtp_data_in(32*i+31 downto 32*i),
      TXOUTCLK                 => txoutclk(i),
      TXOUTCLKPCS              => open,
      TXRESET                  => rst,
      TXUSRCLK                 => gtp_clk2x,
      TXUSRCLK2                => gtp_clk,
      ---------------- Transmit Ports - TX Driver and OOB signaling --------------
      TXBUFDIFFCTRL            => "100",
      TXDIFFCTRL               => TXDIFFCTRL(4*i+3 downto 4*i),--TXDIFFCTRL,
      TXINHIBIT                => tied_to_ground_i,
      TXN                      => tx_n(3-i),
      TXP                      => tx_p(3-i),
      TXPOSTEMPHASIS           => TXPOSTEMPHASIS(8*i+4 downto 8*i),
      --------------- Transmit Ports - TX Driver and OOB signalling --------------
      TXPREEMPHASIS            => TXPREEMPHASIS(4*i+3 downto 4*i),
      ----------- Transmit Ports - TX Elastic Buffer and Phase Alignment ---------
      TXBUFSTATUS              => open,
      -------- Transmit Ports - TX Elastic Buffer and Phase Alignment Ports ------
      TXDLYALIGNDISABLE        => tied_to_vcc_i,
      TXDLYALIGNMONITOR        => open,
      TXDLYALIGNOVERRIDE       => tied_to_ground_i,
      TXDLYALIGNRESET          => tied_to_ground_i,
      TXDLYALIGNUPDSW          => tied_to_vcc_i,
      TXENPMAPHASEALIGN        => tied_to_ground_i,
      TXPMASETPHASE            => tied_to_ground_i,
      ----------------------- Transmit Ports - TX PLL Ports ----------------------
      GREFCLKTX                => tied_to_ground_i,
      GTXTXRESET               => rst,
      MGTREFCLKTX              => gtx0_mgtrefclk,
      NORTHREFCLKTX            => tied_to_ground_vec_i(1 downto 0),
      PERFCLKTX                => tied_to_ground_i,
      PLLTXRESET               => rst,
      SOUTHREFCLKTX            => tied_to_ground_vec_i(1 downto 0),
      TXPLLLKDET               => pll_lock(i),
      TXPLLLKDETEN             => tied_to_vcc_i,
      TXPLLPOWERDOWN           => tied_to_ground_i,
      TXPLLREFSELDY            => tied_to_ground_vec_i(2 downto 0),
      TXRATE                   => tied_to_ground_vec_i(1 downto 0),
      TXRATEDONE               => open,
      TXRESETDONE              => rx_status(3*i+1),
      --------------------- Transmit Ports - TX PRBS Generator -------------------
      TXENPRBSTST              => tied_to_ground_vec_i(2 downto 0),
      TXPRBSFORCEERR           => tied_to_ground_i,
      -------------------- Transmit Ports - TX Polarity Control ------------------
      TXPOLARITY               => tied_to_ground_i,
      ----------------- Transmit Ports - TX Ports for PCI Express ----------------
      TXDEEMPH                 => tied_to_ground_i,
      TXDETECTRX               => tied_to_ground_i,
      TXELECIDLE               => tied_to_ground_i,
      TXMARGIN                 => tied_to_ground_vec_i(2 downto 0),
      TXPDOWNASYNCH            => tied_to_ground_i,
      TXSWING                  => tied_to_ground_i,
      --------------------- Transmit Ports - TX Ports for SATA -------------------
      COMFINISH                => open,
      TXCOMINIT                => tied_to_ground_i,
      TXCOMSAS                 => tied_to_ground_i,
      TXCOMWAKE                => tied_to_ground_i

      );

  align(i) <= rx_reset_done(i) and en_comma_align;
  rx_status(3*i) <= rx_reset_done(i);

  end generate gen_gtx;

  rx_loss_of_sync(15 downto 8) <= (others => '0');
  rx_status(23 downto 12) <=  (others => '0');

end v6lx_x4;
