quit -sim
set VAR_DIR admxrc7k1

# Select MIG7 version: 1_6
if { $argc == 0 } {
  set VAR_MIG 1_6
} else {
  set VAR_MIG $1
}

set VAR_MIG_GEN  gen_ddr3_if_mig7_v${VAR_MIG}
set VAR_MIG_ROOT ddr3_sdram_if
set VAR_MIG_PATH ${VAR_MIG_ROOT}/${VAR_DIR}/mig7_v${VAR_MIG}/rtl

# Execute script to generate 'today package'
exec xtclsh ../gen_today_pkg.tcl today_pkg_${VAR_DIR}_sim.vhd >today_pkg_${VAR_DIR}_sim.vhd

# Delete existing libraries
file delete -force -- work
vlib work

# Compile source code
# DDR3 MIG7 Core
if { ${VAR_MIG} ne "LWB" } then {
if { [catch {
  vlog -incr "../../../common/${VAR_MIG_PATH}/ui/ui_cmd.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ui/ui_rd_data.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ui/ui_wr_data.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ui/ui_top.v"

  vlog -incr "../../../common/${VAR_MIG_PATH}/ecc/ecc_merge_enc.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ecc/ecc_dec_fix.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ecc/ecc_buf.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ecc/ecc_gen.v"

  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_byte_group_io.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_byte_lane.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_calib_top.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_if_post_fifo.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_mc_phy.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_mc_phy_wrapper.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_of_pre_fifo.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_4lanes.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_ck_addr_cmd_delay.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_dqs_found_cal.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_init.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_rdlvl.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_wrcal.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_wrlvl.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_prbs_gen.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_top.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/phy/ddr_phy_oclkdelay_cal.v"

  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/arb_mux.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/arb_row_col.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/arb_select.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/bank_cntrl.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/bank_common.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/bank_compare.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/bank_mach.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/bank_queue.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/bank_state.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/col_mach.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/rank_cntrl.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/rank_common.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/rank_mach.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/round_robin_arb.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/controller/mc.v"

  vlog -incr "../../../common/${VAR_MIG_PATH}/clocking/infrastructure.v"

  vlog -incr "../../../common/${VAR_MIG_PATH}/ip_top/mem_intfc.v"
  vlog -incr "../../../common/${VAR_MIG_PATH}/ip_top/memc_ui_top_std.v"
} msg] } then {
  echo
  echo All DDR3 MIG7 ${VAR_MIG} files for ${VAR_DIR} are not found.
  echo
  echo Please re-run this macro file after generating the
  echo DDR3 MIG7 ${VAR_MIG} files by running
  echo
  echo   xtclsh ${VAR_MIG_GEN}.tcl ${VAR_DIR}
  echo
  echo in a command console in directory:
  echo
  echo   hdl/vhdl/common/${VAR_MIG_ROOT}
  echo
  return -1
} else {
  echo
  echo All DDR3 MIG7 ${VAR_MIG} files for ${VAR_DIR} are found.
  echo }
} else {
  echo
  echo MIG LWB model not supported by Full MPTL simulation.
  echo
  return -1
}

# ADB3 OCP library
vcom -93 "../../../common/adb3_ocp/adb3_ocp_pkg.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_comp_pkg.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_cross_clk_dom.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_retime_nb.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_simple_bus_if.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_simple_bus_if_nb.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_split_b.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_split_nb.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_mux_nb.vhd"
vcom -93 "../../../common/adb3_ocp/adb3_ocp_ocp2ddr3_nb_s7.vhd"

# ADB3 Target
vcom -93 "../../../common/adb3_target/${VAR_DIR}/mptl_target/mptl_if_target_netlist_${VAR_DIR}.vhd"
vcom -93 "../../../common/adb3_target/${VAR_DIR}/adb3_target_inc_pkg_syn_ngc_${VAR_DIR}.vhd"
vcom -93 "../../../common/adb3_target/${VAR_DIR}/mptl_target/mptl_if_target_wrap_${VAR_DIR}.vhd"

# Memory Interface
vcom -93 "../../../common/ddr3_sdram_if/ddr3_if_pkg_k7.vhd"
vcom -93 "../../../common/${VAR_MIG_ROOT}/${VAR_DIR}/mig7_v${VAR_MIG}/ddr3_if_bank_${VAR_DIR}_mig7_v${VAR_MIG}.vhd"

# Memory Applications
vcom -93 "../../../common/mem_apps/blk_mem_test.vhd"

# Chipscope simulation block (optional)
vcom -93 "../../../common/chipscope/blk_chipscope_sim.vhd"

# Uber design
vcom -93 "../${VAR_DIR}/today_pkg_${VAR_DIR}_sim.vhd"
vcom -93 "../common/uber_pkg_s7.vhd"
vcom -93 "../${VAR_DIR}/blk_clocks_${VAR_DIR}.vhd"
vcom -93 "../common/blk_ds_simple_test.vhd"
vcom -93 "../common/blk_clock_freq.vhd"
vcom -93 "../${VAR_DIR}/blk_ds_clk_read_${VAR_DIR}.vhd"
vcom -93 "../${VAR_DIR}/blk_ds_io_test_${VAR_DIR}.vhd"
vcom -93 "../common/blk_ds_int_test.vhd"
vcom -93 "../common/blk_ds_mem_reg.vhd"
vcom -93 "../common/blk_ds_info.vhd"
vcom -93 "../common/blk_direct_slave.vhd"
vcom -93 "../common/bram_single_wrap_s7.vhd"
vcom -93 "../common/blk_bram.vhd"
vcom -93 "../common/blk_dma_switch.vhd"
vcom -93 "../common/blk_mem_app.vhd"
vcom -93 "../${VAR_DIR}/blk_mem_if_${VAR_DIR}.vhd"
vcom -93 "../common/uber_s7.vhd"

# Compile testbench source code
# Full DDR3 SDRAM model
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram_pkg.vhd"
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram_int_pkg.vhd"
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram_dly_cnt.vhd"
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram_timing_chk.vhd"
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram_main_fsm.vhd"
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram_init_fsm.vhd"
vcom -93 "../../../common/mem_tb/ddr3_sdram/ddr3_sdram.vhd"

# ADB3 OCP testbench
vcom -93 "../../../common/adb3_ocp/adb3_ocp_tb_pkg.vhd"

# ADB3 OCP probe
vcom -93 "../../../common/adb3_probe/adb3_probe_pkg.vhd"
vcom -93 "../../../common/adb3_probe/adb3_ocp_transaction_probe_sim.vhd"

# ADB3 Target
vcom -93 "../../../common/adb3_target/${VAR_DIR}/adb3_target_tb_inc_pkg_${VAR_DIR}.vhd"
vcom -93 "../../../common/adb3_target/${VAR_DIR}/mptl_bridge/mptl128_gtx6_interface.vhd"
vcom -93 "../../../common/adb3_target/${VAR_DIR}/mptl_bridge/mptl_if_bridge_netlist_${VAR_DIR}.vhd"
vcom -93 "../../../common/adb3_target/${VAR_DIR}/mptl_bridge/mptl_if_bridge_wrap_${VAR_DIR}.vhd"
vcom -93 "../../../common/adb3_target/${VAR_DIR}/test_board_clks_${VAR_DIR}.vhd"

# Testbench
vcom -93 "../${VAR_DIR}/uber_tb_pkg_${VAR_DIR}.vhd"
vcom -93 "../common/test_uber_ds.vhd"
vcom -93 "../common/test_uber_dm.vhd"
vcom -93 "../common/test_uber_dma_1ch_nb.vhd"
vcom -93 "../common/test_uber_probes.vhd"
vcom -93 "../${VAR_DIR}/test_uber_mem_${VAR_DIR}.vhd"
vcom -93 "../common/test_uber.vhd"

#
vlog "$env(XILINX)/verilog/src/glbl.v"

# Define level of on-board RAM model message reporting
set VAR_MESSAGE_LEVEL 0

vsim -t fs -novopt +notimingchecks -L unisims_ver -L secureip -Gmessage_level=${VAR_MESSAGE_LEVEL} test_uber glbl

set VAR_USE        Full_MPTL
set VAR_SER_WIDTH  [examine /adb3_target_inc_pkg/MPTL_SER_WIDTH]
set VAR_DDR3_BANKS [examine /adb3_target_inc_pkg/DDR3_BANKS]

set VAR_MODEL      [examine /adb3_target_tb_inc_pkg/MODEL_NAME]
set VAR_DDR3_SIZE  [examine /adb3_target_tb_inc_pkg/OPTION_M]

set wave_pat {
/test_uber/*
/test_uber/uut/*

/test_uber/uut/blk_direct_slave_i/*
/test_uber/uut/blk_direct_slave_i/blk_ds_clk_read_i/*

/test_uber/uut/blk_dma_switch_i/*
/test_uber/uut/blk_dma_switch_i/dma_split_g__0/adb3_ocp_split_nb_dma_i/*
/test_uber/uut/blk_dma_switch_i/mux_ram_g__1/adb3_ocp_mux_nb_ram_i/*

/test_uber/uut/blk_bram_i/*

/test_uber/uut/blk_mem_if_i/*
/test_uber/uut/blk_mem_if_i/ddr3_if_g__1/ddr3_if_bank_i/*
}

set wave_rad {
hexadecimal {data q}
}

view signals
view structure
view wave -title "uber (${VAR_MODEL}, MPTLx${VAR_SER_WIDTH}, ${VAR_DDR3_BANKS}x1x${VAR_DDR3_SIZE}Gib DDR3, MIG7 ${VAR_MIG}, ${VAR_USE})"

foreach pattern $wave_pat {
add wave -group $pattern $pattern
}
configure wave -signalnamewidth 1

foreach {radix signals} $wave_rad {
foreach signal $signals {
catch {property wave -radix $radix $signal}
}
}

radix hex
# Disabled for Coregen MIG DDR3 SDRAM interface
set NumericStdNoWarnings 1
set StdArithNoWarnings 1

if { $argc <= 1 } {
  run 1 ms
} else {
  run $2
  quit -sim
}